/* $Id: fullfactor_help.gp,v 1.4 2008-01-08 14:13:03 jdemeyer Exp $ */

{addhelp(fullfactor, "fullfactor(x,{factorfunc = z->factor(z)}): "
"if x is not a matrix, call factorfunc(x). "
"If x a matrix, it is assumed to be a factorisation matrix. "
"In this case, return a further factorisation by doing a factorisation in coprimes, "
"then applying factorfunc(z) on the factors z in the factorisation matrix. "
"factorfunc can also be a vector of functions, "
"in which case the various functions are applied from left to right: "
"fullfactor(x, [f,g]) is equivalent to fullfactor(fullfactor(x,f),g)."
)}

{addhelp(radical, "radical(x,{factorfunc}): "
"return the radical of x, the product of the distinct prime factors of x. "
"If x is a matrix, it is assumed to be a factorisation. "
"Otherwise, factor(x) will be called if no factorfunc is specified. "
"If factorfunc is given, fullfactor(x,factorfunc) will always be called, "
"whether or not x is a matrix."
)}

{addhelp(factor_default, "factor_default(x): "
"return factor(x)."
)}

{addhelp(factor_coprime, "factor_coprime(x): "
"return x, can be used as a factorfunc for fullfactor() "
"in order to factor in coprimes."
)}

{addhelp(factor_trialdiv, "factor_trialdiv(x): "
"return factor(x,0)."
)}

{addhelp(factor_above_primelimit, "factor_above_primelimit(x): "
"if x is an integer above primelimit, return x; "
"otherwise, return an empty matrix. "
"When used as a factorfunc, keep only those factors in a factorisation "
"which are at least primelimit. "
"Smaller factors will be removed from the factorisation."
)}

{addhelp(factor_power, "factor_power(x): "
"check whether x is a perfect power and return a factorisation matrix "
"of the form Mat([r,n]), where x = r^n."
)}

{addhelp(factor_check, "factor_check(x): "
"give an error if x is a composite integer (checked with isprime) or reducible polynomial, "
"otherwise return x. "
"When used as a factorfunc for fullfactor(), "
"it will check all factors and either give an error or return the factorisation."
)}

{addhelp(split_factor_gcd, "split_factor_gcd(x,v): "
"Given a vector v, tries to factor x by taking gcd's between x and elements of v. "
"For all i<j, gcd(v[i],v[j],x) should be either 1 or equal to gcd(v[i],x). "
"Return [F,c] where c is the cofactor such that gcd(c,v[i]) = 1 for all v[i] in v, "
"and F is a partial factorisation of x/c. "
"See also factor_gcd()."
)}

{addhelp(factor_gcd, "factor_gcd(v)(x): "
"given a vector v, return a partial factorisation of x "
"obtained by taking gcd's between x and elements of v. "
"For all i<j, gcd(v[i],v[j],x) should be either 1 or equal to gcd(v[i],x). "
"If v is not a vector, it is interpreted as [v]. "
"factor_gcd(v) is meant to be used as a factorfunc for fullfactor, "
"for example fullfactor(120, factor_gcd([6,7])). "
"Internally, factor_gcd(v) returns a t_CLOSURE which calls split_factor_gcd()."
)}

{addhelp(factor_squarefree, "factor_squarefree(pol): "
"return squarefree factorisation of the polynomial pol."
)}

{addhelp(factor_cyclo, Str("factor_cyclo(x): "
"first does trial division on x, then does so-called \"cyclotomic factoring\". "
"The latter means that we find factors which divide polcyclo(e,b) with "
"e and b \"small\". "
"If we found such a factor, we do Aurifeuillian factorisation if applicable. "
,
if (fullfactor_datadir != "",
	"We also look up known factors in the fullfactor data."
,
	"If you would install the fullfactor data, we could also look up known factors."
)
))}

{addhelp(factor_cyclo1, "factor_cyclo1(x, flag=0): "
"find cyclotomic factors of x, see factor_cyclo(). "
"This function should only be used after trial division up to 500000. "
"If flag equals 1, return a 4-column factorisation matrix instead, "
"where every row is [factor, power, base, exponent]. "
"Here, factor and power are the usual two columns, "
"and factor is a divisor of polcyclo(exponent, base)."
)}

{addhelp(split_factor_cyclo, Str("split_factor_cyclo(x,b,e): "
"given a number x, extract all factors of polcyclo(e,b) by doing "
"Aurifeuillian factorisation"
,
if (fullfactor_datadir != "",
	" and table lookup. "
,
	". If you would install the fullfactor data, table lookup would also be done. "
)
,
"Return [F,c] where c is the maximal divisor of x such that gcd(c,b^e-1) = 1 "
"and F is a partial factorisation of x/c."
))}

{addhelp(partial_factor_pn_1, "partial_factor_pn_1(b,n): "
"return partial factorisation of b^n - 1. "
"If you want a full factorisation of b^n - 1, "
"try fullfactor(partial_factor_pn_1(b,n)). "
"Note that b does not need to be prime."
)}

{addhelp(polaurif, "polaurif(b,{x='x}): "
"given a squarefree integer b, "
"return a non-trivial factor of polcyclo(b, b*x^2) if b = 1 mod 4; "
"return a non-trivial factor of polcyclo(2*b, b*x^2) if b = 2,3 mod 4. "
"x can be either a polynomial variable or a point at which to evaluate the polynomial."
)}

{addhelp(isprimepower, "isprimepower(x): "
"if x is not prime nor a prime power, return 0. "
"If x = p^n, return p."
)}

{addhelp(nextprimepower, "nextprimepower(x): "
"return smallest prime or prime power >= x."
)}

{addhelp(nextprimepower, "precprimepower(x): "
"return largest prime or prime power <= x."
)}

{addhelp(gcdmod, "gcdmod(x): "
"given a INTMOD or POLMOD x, return the gcd of x with its modulus. "
"This is the factor which prevents x from being invertible."
)}

{addhelp(logint, "logint(x,{b=2}): "
"floor(log(x)/log(b)) where x and b are positive integers."
)}

{addhelp(Vecflat, "Vecflat(x): "
"convert x to a vector using Vec(x). "
"Then flatten that vector, for example "
"Vecflat([[[a,[b]],[c,[d,e]]]]) = [a,b,c,d,e]."
)}

{addhelp(fullfactor_initialise, "fullfactor_initialise(): "
"initialise the fullfactor package: locate the fullfactor data "
"in the paths specified by default(path) and default(datadir). "
"Also set the default bases for factor_cyclo to 2, ..., 99."
)}
